@@ -1,4 +1,4 @@
-#  Jnterface.pm
+#  Interface.pm
 #    - providing an object-oriented approach to interacting with GnuPG
 #
 #  Copyright (C) 2000 Frank J. Tobin <ftobin@cpan.org>
@@ -12,7 +12,8 @@
 #
 
 package GnuPG::Interface;
-use Any::Moose;
+use Moo;
+use MooX::late;
 with qw(GnuPG::HashInit);
 
 use English qw( -no_match_vars );
@@ -27,7 +28,7 @@ use Math::BigInt try => 'GMP';
 use GnuPG::Options;
 use GnuPG::Handles;
 
-$VERSION = '0.42_02';
+$VERSION = '0.47_01';
 
 has $_ => (
     isa     => 'Any',
@@ -120,6 +121,8 @@ sub fork_attach_exec( $% ) {
         = ref $args{command_args}
         ? @{ $args{command_args} }
         : ( $args{command_args} || () );
+    unshift @command_args, "--"
+        if @command_args and $command_args[0] ne "--";
 
     my %fhs;
     foreach my $fh_name (
@@ -415,7 +418,7 @@ sub get_keys {
     while (<$stdout>) {
         my $line = $_;
         chomp $line;
-        my @fields = split ':', $line;
+        my @fields = split ':', $line, -1;
         next unless @fields > 3;
 
         my $record_type = $fields[0];
@@ -745,6 +748,25 @@ sub send_keys( $% ) {
     );
 }
 
+sub search_keys( $% ) {
+    my ( $self, %args ) = @_;
+    return $self->wrap_call(
+        %args,
+        commands => ['--search-keys']
+    );
+}
+
+sub version {
+    my ( $self ) = @_;
+
+    my $out = IO::Handle->new;
+    my $handles = GnuPG::Handles->new( stdout => $out );
+    $self->wrap_call( commands => [ '--version' ], handles => $handles );
+    my $line = $out->getline;
+    $line =~ /(\d+\.\d+\.\d+)/;
+    return $1;
+}
+
 sub test_default_key_passphrase() {
     my ($self) = @_;
 
@@ -846,7 +868,7 @@ decryption, verification, and key-listing parsing.
 =head2 How Data Member Accessor Methods are Created
 
 Each module in the GnuPG::Interface bundle relies
-on Any::Moose to generate the get/set methods
+on Moo to generate the get/set methods
 used to set the object's data members.
 I<This is very important to realize.>  This means that
 any data member which is a list has special
@@ -928,6 +950,8 @@ initialization of data members.
 
 =item send_keys( % )
 
+=item search_keys( % )
+
 These methods each correspond directly to or are very similar
 to a GnuPG command described in L<gpg>.  Each of these methods
 takes a hash, which currently must contain a key of B<handles>
@@ -1009,6 +1033,10 @@ while signing a short message using the values of
 the B<passphrase> data member, and the default
 key specified in the B<options> data member.
 
+=item version()
+
+Returns the version of GnuPG that GnuPG::Interface is running.
+
 =back
 
 
@@ -1097,7 +1125,7 @@ The following setup can be done before any of the following examples:
   $gnupg->options->hash_init( armor    => 1,
                               recipients => [ 'ftobin@uiuc.edu',
                                               '0xABCD1234' ],
-                              meta_interactive( 0 ),
+                              meta_interactive => 0 ,
                             );
 
 =head2 Encrypting
@@ -1202,9 +1230,9 @@ The following setup can be done before any of the following examples:
   close $input;
   close $cipher_file;
 
-  my @plaintext    = <$output>;   # reading the output
-  my @error_output = <$error>;    # reading the error
-  my @status_info  = <$status_fh> # read the status info
+  my @plaintext    = <$output>;    # reading the output
+  my @error_output = <$error>;     # reading the error
+  my @status_info  = <$status_fh>; # read the status info
 
   # clean up...
   close $output;
@@ -1324,8 +1352,5 @@ Frank J. Tobin, ftobin@cpan.org was the original author of the package.
 
 =cut
 
-
-__PACKAGE__->meta->make_immutable;
-
 1;
 
