@@ -14,8 +14,9 @@
 #
 
 package GnuPG::Options;
-use Moose;
-use MooseX::AttributeHelpers;
+use Moo;
+use MooX::late;
+use MooX::HandlesVia;
 with qw(GnuPG::HashInit);
 
 use constant BOOLEANS => qw(
@@ -70,16 +71,18 @@ has $_ => (
     clearer => 'clear_' . $_,
 ) for SCALARS;
 
-has $_ => (
-    isa        => 'ArrayRef',
-    is         => 'rw',
-    lazy       => 1,
-    clearer    => 'clear_' . $_,
-    default    => sub { [] },
-    auto_deref => 1,
-    metaclass  => 'Collection::Array',
-    provides   => { push => 'push_' . $_ },
-) for LISTS;
+for my $list (LISTS) {
+    has $list => (
+        handles_via => 'Array',
+        is          => 'rw',
+        lazy        => 1,
+        clearer     => "clear_$list",
+        default     => sub { [] },
+        handles     => {
+            "push_$list" => 'push',
+        },
+    );
+}
 
 sub BUILD {
     my ( $self, $args ) = @_;
@@ -94,7 +97,7 @@ sub copy {
 
     foreach my $field ( BOOLEANS, SCALARS, LISTS ) {
         my $value = $self->$field();
-        next unless $value;
+        next unless defined $value;
         $new->$field($value);
     }
 
@@ -107,7 +110,7 @@ sub get_args {
     return (
         $self->get_meta_args(),
         $self->get_option_args(),
-        $self->extra_args(),
+        @{$self->extra_args()},
     );
 }
 
@@ -144,8 +147,8 @@ sub get_option_args {
     push @args, '--command-fd', $self->command_fd()
         if defined $self->command_fd();
 
-    push @args, map { ( '--recipient',  $_ ) } $self->recipients();
-    push @args, map { ( '--encrypt-to', $_ ) } $self->encrypt_to();
+    push @args, map { ( '--recipient',  $_ ) } @{$self->recipients};
+    push @args, map { ( '--encrypt-to', $_ ) } @{$self->encrypt_to};
 
     return @args;
 }
@@ -169,9 +172,10 @@ sub get_meta_args {
         if $self->meta_signing_key();
 
     push @args,
-        map { ( '--recipient', $_ ) } $self->meta_recipients_key_ids();
+        map { ( '--recipient', $_ ) } @{$self->meta_recipients_key_ids};
+    use Data::Dumper::Concise;
     push @args,
-        map { ( '--recipient', $_->hex_id() ) } $self->meta_recipients_keys();
+        map { ( '--recipient', $_->hex_id() ) } @{$self->meta_recipients_keys};
 
     return @args;
 }
@@ -267,6 +271,8 @@ and then I<extra_args>, in that order.
 
 =item recipients
 
+=back
+
 These options correlate directly to many GnuPG options.  For those that
 are boolean to GnuPG, simply that argument is passed.  For those
 that are associated with a scalar, that scalar is passed passed
@@ -292,6 +298,8 @@ an object shall be prepended with I<_id(s)> if they only
 take an id; otherwise assume an object of type GnuPG::Key
 is required.
 
+=over 4
+
 =item meta_pgp_5_compatible
 
 If true, arguments are generated to try to be compatible with PGP 5.x.
